@@ -171,7 +171,7 @@ update_types_dict = {
 }
 
 
-def update_value_type(fields, item, key, db="ch"):
+def update_value_type(fields, item, key, db="ch", dict_replace_str={}):
     """
     :param db: db to update
     :param fields: dict - key  type
@@ -204,6 +204,8 @@ def update_value_type(fields, item, key, db="ch"):
         item[key] = bool(item[key])
     else:
         item[key] = str(item[key])
+        for key_replace in dict_replace_str:
+            item[key] = item[key].replace(key_replace, dict_replace_str[key_replace])
     return item
 
 
@@ -330,7 +332,11 @@ class FieldsConverterOneWay:
             cred["database"],
         )
 
-        engine = create_engine(uri_sql_alchemy)
+        if "connect_args" in self.sql_credentials[self.db]:
+            connect_args = self.sql_credentials[self.db]["connect_args"]
+        else:
+            connect_args = {}
+        engine = create_engine(uri_sql_alchemy, connect_args=connect_args)
         self.conn = engine.connect()
         self.log("connecting to {} successfull".format(self.db))
         if "schema" in cred:
@@ -367,8 +373,9 @@ class FieldsConverterOneWay:
     def __del__(self):
         self.conn.close()
 
-    def update_value_type(self, table_name, items):
+    def update_value_type(self, table_name, items, dict_replace_str={}):
         """
+        :param dict_replace_str: replace in string dict
         :param items: list of dicts to update
         :param table_name: table_name to insert
         :return:
@@ -377,7 +384,9 @@ class FieldsConverterOneWay:
         keys = fields.keys()
         for item in items:
             for key in keys:
-                item = update_value_type(fields, item, key, db=self.db)
+                item = update_value_type(
+                    fields, item, key, db=self.db, dict_replace_str=dict_replace_str
+                )
         return items
 
     def get_columns(self, table_name):
@@ -447,10 +456,19 @@ class FieldsConverter:
             cred_to["database"],
         )
         self.quote_char = quotes_dict[self.to_db]
-        engine_from = create_engine(uri_sql_alchemy_from)
+        if "connect_args" in self.sql_credentials[self.from_db]:
+            connect_args = self.sql_credentials[self.from_db]["connect_args"]
+        else:
+            connect_args = {}
+        engine_from = create_engine(uri_sql_alchemy_from, connect_args=connect_args)
         self.conn_from = engine_from.connect()
         self.log("connecting to {} successfull".format(self.from_db))
-        engine_to = create_engine(uri_sql_alchemy_to)
+
+        if "connect_args" in self.sql_credentials[self.to_db]:
+            connect_args = self.sql_credentials[self.to_db]["connect_args"]
+        else:
+            connect_args = {}
+        engine_to = create_engine(uri_sql_alchemy_to, connect_args=connect_args)
         self.conn_to = engine_to.connect()
         self.log("connecting to {} successfull".format(self.to_db))
         if "schema" in cred_from:
